logging

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 10, 2023 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	LogFieldVolume       = "volume"
	LogFieldVolumeDev    = "volume_dev"
	LogFieldVolumeName   = "volume_name"
	LogFieldOrigVolume   = "original_volume"
	LogFieldSnapshot     = "snapshot"
	LogFieldBackup       = "backup"
	LogFieldBackupType   = "backup_type"
	LogFieldLastBackup   = "last_backup"
	LogFieldLastSnapshot = "last_snapshot"
	LogEventBackupURL    = "backup_url"
	LogFieldDestURL      = "dest_url"
	LogFieldSourceURL    = "source_url"
	LogFieldKind         = "kind"
	LogFieldFilepath     = "filepath"

	LogFieldEvent        = "event"
	LogEventBackup       = "backup"
	LogEventList         = "list"
	LogEventRestore      = "restore"
	LogEventRestoreIncre = "restore_incrementally"
	LogEventCompare      = "compare"

	LogFieldReason    = "reason"
	LogReasonStart    = "start"
	LogReasonComplete = "complete"
	LogReasonFallback = "fallback"

	LogFieldObject    = "object"
	LogObjectBackup   = "backup"
	LogObjectSnapshot = "snapshot"
	LogObjectConfig   = "config"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Error

type Error struct {
	// contains filtered or unexported fields
}

Error is a wrapper for a go error contains more details

func ErrorWithFields

func ErrorWithFields(pkg string, fields logrus.Fields, format string, v ...interface{}) Error

ErrorWithFields is a helper for searchable error fields output

Jump to